Contain all the code for this projet with the Config enum and its functions the run, the search and the search_case_insensitive functions
Structs
Functions
- run
- Call search or search_case_insensitive depending on the IGNORE_CASE environnement variable
- search
- Get only lines of contents that contains the query string. Sensitive to caps.
- search_
case_ insensitive - Get only lines of contents that contains the query string. Insensitive to caps.